@@ -7,8 +7,12 @@ from .custom_bot import CustomBot
 
 
 class CustomCog(OriginalCog):
-    """A simple lil wrapper around the original discord Cog class that just adds a
-    logger for me to use"""
+    """
+    A simple lil wrapper around the original discord Cog class that just adds a logger for me to use.
+
+    Attributes:
+        logger (logging.Logger): The logger that's assigned to the cog instance.
+    """
 
     def __init__(self, bot:CustomBot, logger_name:str=None):
         self.bot = bot
@@ -19,11 +23,15 @@ class CustomCog(OriginalCog):
             self.logger = bot_logger.getChild(self.get_logger_name())
 
     def get_logger_name(self, *prefixes, sep:str='.') -> str:
-        """Gets the name of the class with any given prefixes, with sep as a seperator"""
+        """
+        Gets the name of the class with any given prefixes, with sep as a seperator.
+        """
 
         return sep.join(['cog'] + list(prefixes) + [self.__cog_name__.replace(' ', '')])
 
     def get_name(self) -> str:
-        """Gets the name of the class as a nice ol' space-seperated thingmie"""
+        """
+        Gets the "human readable" name of the class.
+        """
 
         return regex.sub(r"(?:[A-Z])(?:(?:[a-z0-9])+|[A-Z]+$|[A-Z]+(?=[A-Z]))?", "\\g<0> ", self.__cog_name__.replace(' ', '')).strip()
