@@ -7,10 +7,13 @@ from .checks.meta_command import InvokedMetaCommand
 
 
 class CustomCommand(commands.Command):
+    """
+    A custom command object for wrapping our commands with.
+    """
 
     def __init__(self, *args, **kwargs):
         super().__init__(*args, cooldown_after_parsing=kwargs.pop('cooldown_after_parsing', True), **kwargs)
-        self.ignore_checks_in_help = kwargs.get('ignore_checks_in_help', False)
+        self.ignore_checks_in_help: bool = kwargs.get('ignore_checks_in_help', False)
 
         # Fix cooldown to be our custom type
         cooldown = self._buckets._cooldown
@@ -25,22 +28,24 @@ class CustomCommand(commands.Command):
         self._buckets = mapping(cooldown)  # Wrap the cooldown in the mapping
 
     def get_remaining_cooldown(self, ctx:commands.Context, current:float=None) -> typing.Optional[float]:
-        """Gets the remaining cooldown for a given command"""
+        """
+        Gets the remaining cooldown for a given command.
+
+        Args:
+            ctx (commands.Context): The context object for the command/author.
+            current (float, optional): The current time.
+
+        Returns:
+            typing.Optional[float]: The remaining time on the user's cooldown or `None`.
+        """
 
         bucket = self._buckets.get_bucket(ctx.message)
         return bucket.get_remaining_cooldown()
 
-    async def invoke_ignoring_meta(self, ctx):
-        """Invokes the given ctx, reinvoking when it reaches an InvokedMetaCommand error
-        Throws any other error it finds as normal"""
-
-        try:
-            return await self.invoke(ctx)
-        except InvokedMetaCommand:
-            return await ctx.reinvoke()
-
     def _prepare_cooldowns(self, ctx:commands.Context):
-        """Prepares all the cooldowns for the command to be called"""
+        """
+        Prepares all the cooldowns for the command to be called.
+        """
 
         if self._buckets.valid:
             current = ctx.message.created_at.replace(tzinfo=datetime.timezone.utc).timestamp()
@@ -65,8 +70,16 @@ class CustomGroup(commands.Group):
         super().__init__(*args, cooldown_after_parsing=kwargs.get('cooldown_after_parsing', True), **kwargs)
         self.ignore_checks_in_help = kwargs.get('ignore_checks_in_help', False)
 
-    async def can_run(self, ctx:commands.Context):
-        """The normal Command.can_run but it ignores cooldowns"""
+    async def can_run(self, ctx:commands.Context) -> bool:
+        """
+        The normal Command.can_run but it ignores cooldowns.
+
+        Args:
+            ctx (commands.Context): The command we want to chek if can be run.
+
+        Returns:
+            bool: Whether or not the command can be run.
+        """
 
         if self.ignore_checks_in_help:
             return True
@@ -74,5 +87,3 @@ class CustomGroup(commands.Group):
             return await super().can_run(ctx)
         except commands.CommandOnCooldown:
             return True
-        except commands.CommandError as e:
-            raise e
